(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     15680,        401]
NotebookOptionsPosition[     13124,        355]
NotebookOutlinePosition[     13680,        376]
CellTagsIndexPosition[     13637,        373]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 10, Section 10.3.1, Figure 10.7", "Section",ExpressionUUID->"7e06fb0b-b50b-4986-8198-f2824b77e2f7"],

Cell[TextData[{
 "The functions defined here are those already used in, for example, ",
 StyleBox["Fig.8.1\[Dash]8.3.nb",
  FontWeight->"Bold"],
 ".\n\nWe start by defining the radius as a function of semi-major axis, \
eccentricity and true anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5f0e487f-5a05-4501-a484-5513630a1177"],

Cell["r[a_,e_,t_]:=a(1-e^2)/(1+e Cos[t]);", "Input",
 AspectRatioFixed->False,
 CellLabel->"In[1]:=",ExpressionUUID->"f1ac7d12-1b5d-456a-b022-d764ffe5f377"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bbf09ff6-0254-43f2-80f3-ed48a7ada745"],

Cell["ksolve[ma_,e_]:=FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 AspectRatioFixed->False,
 CellLabel->"In[2]:=",ExpressionUUID->"24b49598-4151-4592-b0ba-fe777d476055"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9d33ae34-2de9-425a-b329-7615d03f9e1e"],

Cell["\<\
position[ma_,a_,e_]:=
Module[{eca, x, y},
  eca = ea /. ksolve[ma,e];
  x = N[a(Cos[eca]-e)]; 
  y = N[a Sqrt[1-e^2] Sin[eca]];
  {x,y}]\
\>", "Input",
 AspectRatioFixed->False,
 CellLabel->"In[3]:=",ExpressionUUID->"118ce487-2ef8-4f01-9da6-c911a1ca4645"],

Cell[TextData[{
 "We set the list of points, ",
 StyleBox["rotlist", "Input"],
 ", to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"87ea0d06-ccf5-4b06-a499-85401135ab16"],

Cell["rotlist={};", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[4]:=",ExpressionUUID->"1d00279c-a5d8-4a27-915b-ba1d9b2c21e0"],

Cell["\<\
Define the resonance (3:2), the semi-major axis (unity) and the eccentricity \
(0.25).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3a43e4c7-9d7f-40b8-bf46-38a18da1bae8"],

Cell["p=3/2; a=1.0; e=0.25;", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[5]:=",ExpressionUUID->"143af27d-00c6-4b33-b490-233e12389166"],

Cell["Create the list of points that make up the orbit.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"751d6f93-221d-43c4-8623-0e47a4af5520"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
th=p*t;
psi=th-f;
blip=N[{rad*Cos[psi],rad*Sin[psi]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/20}]\
\>", "Input",
 AspectRatioFixed->False,
 CellLabel->"In[6]:=",ExpressionUUID->"89700eed-edde-4918-8ba9-616e5e7e2067"],

Cell["Plot the points as the path in the rotating frame.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"eb88294c-0d5f-4888-a506-0a70ccd89c06"],

Cell[CellGroupData[{

Cell["\<\
pa=ListPlot[rotlist,AspectRatio->Automatic, 
            PlotJoined->True,Axes->None]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[7]:=",ExpressionUUID->"f79e2b70-ee90-4de0-9967-f354664946c3"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlGlIlFEUhgfNHyahlmWJYmYEBSlSULh0jFySUsfGcIEwtTCyHEmQIHGh
ECXTJNREyyU1TUvDUizhoIONpdFCQhq5gMs4OuO4UGgL1ZzXH30wfAOX795z
nvc51y1Bfeq8hUKhiPj7+/eWR0fr/yoSRr9v3qsjr1hjVMlEOcdl6AdranVU
1z/ZdDP9IfuGXZuySZol69N1lbrIx3x/KtWgTNZTYeBHK5faFt4R+NN98t4c
aS+tWnV+fcDezU4NV6fnqbDgeJmlUc29ThX9hj1GatiobXyX3UQRDV1HXP0W
aG3QIiYgjEn5ozC22sJE7s1vNmg8ByimqifP28NEB3LiMtXRn8jkbeA2exMd
DOgb7B37Qo5DLon5/gukDK7fP7IyQbcdPIdCag2kNAWlqLZMU9nLDo3Kf46S
sorPvHfVU6f9h+wCZx1d3D359LrBQInxreeCjk1S7lzpieRGEw3ucsiqKBkj
g1G59M1uiX6NZ9bX1g3RsFO3W47rMs0ktN8aV7yiNuuIVC/tMlmnDXOrbamv
0Fuh37LOrVifkO95BN8PyP48j/3j5XzOw/nPpD5Wo74iqZ+voH70xyr0t136
53D0vyB8OBR8wI/3gR/48k7wBX+eAn/kwy+Qj4/kx8X5kh/y5efIF/nzXeTv
J37wWqT4cVb8YcvX4g/8YocY8Qv+cd5M+qp+pN23HOue0eZ1gn9cJP6RD/bP
kv2pCueb5HxyRH22l8310WHUvy3HXD/1oL8gG3N/HI7+Pd6a+2cV+Ggfmflw
LPg5Cz82gq+v8GV78I8W/nwH+ZyUfLgG+cVJftyMfNMkX76A/OEfd8APo/jB
i/Dns/jD6kTx64n4xY0Bo9quUE03/OMiWSf4x4qJ//zlavi9iP1T4P8NnF+D
+chAfQ2Yn1jUX475CkF/mzB/Ceh/FvOZCj7gR17gB77UAr6RmH8L8O/D/TCO
fOAfleRKfs64X5KQbwXuH7tgyR/+0SGV+BGP+2sr/KnE/XY0Svxav//EP033
H340svk=
      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0112862913174099`, 1.0112862913174099`}, {-1.25, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.812013302271373*^9, 3.812013506698573*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"0e6c2367-ad9f-4e02-9798-a6d9e76378d1"]
}, Open  ]],

Cell["\<\
Plot the points as individual points aloong the path in the rotating frame.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fd595950-2dfb-43a8-879a-5330b58cefd6"],

Cell[CellGroupData[{

Cell["\<\
pb=
ListPlot[rotlist,AspectRatio->Automatic, Axes->None]\
\>", "Input",
 CellChangeTimes->{{3.812013351629566*^9, 3.812013367467434*^9}},
 AspectRatioFixed->True,
 CellLabel->"In[8]:=",ExpressionUUID->"f40fdf31-0228-48c1-addf-a12bbbbed4fb"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlGlIlFEUhgfNHyahlmWJYmYEBSlSULh0jFySUsfGcIEwtTCyHEmQIHGh
ECXTJNREyyU1TUvDUizhoIONpdFCQhq5gMs4OuO4UGgL1ZzXH30wfAOX795z
nvc51y1Bfeq8hUKhiPj7+/eWR0fr/yoSRr9v3qsjr1hjVMlEOcdl6AdranVU
1z/ZdDP9IfuGXZuySZol69N1lbrIx3x/KtWgTNZTYeBHK5faFt4R+NN98t4c
aS+tWnV+fcDezU4NV6fnqbDgeJmlUc29ThX9hj1GatiobXyX3UQRDV1HXP0W
aG3QIiYgjEn5ozC22sJE7s1vNmg8ByimqifP28NEB3LiMtXRn8jkbeA2exMd
DOgb7B37Qo5DLon5/gukDK7fP7IyQbcdPIdCag2kNAWlqLZMU9nLDo3Kf46S
sorPvHfVU6f9h+wCZx1d3D359LrBQInxreeCjk1S7lzpieRGEw3ucsiqKBkj
g1G59M1uiX6NZ9bX1g3RsFO3W47rMs0ktN8aV7yiNuuIVC/tMlmnDXOrbamv
0Fuh37LOrVifkO95BN8PyP48j/3j5XzOw/nPpD5Wo74iqZ+voH70xyr0t136
53D0vyB8OBR8wI/3gR/48k7wBX+eAn/kwy+Qj4/kx8X5kh/y5efIF/nzXeTv
J37wWqT4cVb8YcvX4g/8YocY8Qv+cd5M+qp+pN23HOue0eZ1gn9cJP6RD/bP
kv2pCueb5HxyRH22l8310WHUvy3HXD/1oL8gG3N/HI7+Pd6a+2cV+Ggfmflw
LPg5Cz82gq+v8GV78I8W/nwH+ZyUfLgG+cVJftyMfNMkX76A/OEfd8APo/jB
i/Dns/jD6kTx64n4xY0Bo9quUE03/OMiWSf4x4qJ//zlavi9iP1T4P8NnF+D
+chAfQ2Yn1jUX475CkF/mzB/Ceh/FvOZCj7gR17gB77UAr6RmH8L8O/D/TCO
fOAfleRKfs64X5KQbwXuH7tgyR/+0SGV+BGP+2sr/KnE/XY0Svxav//EP033
H340svk=
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0112862913174099`, 1.0112862913174099`}, {-1.25, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8120133023180723`*^9, 3.812013354556224*^9, 
  3.812013413785375*^9, 3.8120135067468233`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"62081d7a-69fe-49a9-bdfd-21e6014bb7fa"]
}, Open  ]],

Cell["Show both plots together (see Fig.10.7).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7e42d331-662d-4ea0-adf9-045ef078dbae"],

Cell[CellGroupData[{

Cell["Show[pa,pb]", "Input",
 CellChangeTimes->{{3.81201337566926*^9, 3.812013491170987*^9}},
 AspectRatioFixed->True,
 CellLabel->"In[9]:=",ExpressionUUID->"60d050f5-80a7-4562-a1ae-59a8c770cc66"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxVlGlIlFEUhgfNHyahlmWJYmYEBSlSULh0jFySUsfGcIEwtTCyHEmQIHGh
ECXTJNREyyU1TUvDUizhoIONpdFCQhq5gMs4OuO4UGgL1ZzXH30wfAOX795z
nvc51y1Bfeq8hUKhiPj7+/eWR0fr/yoSRr9v3qsjr1hjVMlEOcdl6AdranVU
1z/ZdDP9IfuGXZuySZol69N1lbrIx3x/KtWgTNZTYeBHK5faFt4R+NN98t4c
aS+tWnV+fcDezU4NV6fnqbDgeJmlUc29ThX9hj1GatiobXyX3UQRDV1HXP0W
aG3QIiYgjEn5ozC22sJE7s1vNmg8ByimqifP28NEB3LiMtXRn8jkbeA2exMd
DOgb7B37Qo5DLon5/gukDK7fP7IyQbcdPIdCag2kNAWlqLZMU9nLDo3Kf46S
sorPvHfVU6f9h+wCZx1d3D359LrBQInxreeCjk1S7lzpieRGEw3ucsiqKBkj
g1G59M1uiX6NZ9bX1g3RsFO3W47rMs0ktN8aV7yiNuuIVC/tMlmnDXOrbamv
0Fuh37LOrVifkO95BN8PyP48j/3j5XzOw/nPpD5Wo74iqZ+voH70xyr0t136
53D0vyB8OBR8wI/3gR/48k7wBX+eAn/kwy+Qj4/kx8X5kh/y5efIF/nzXeTv
J37wWqT4cVb8YcvX4g/8YocY8Qv+cd5M+qp+pN23HOue0eZ1gn9cJP6RD/bP
kv2pCueb5HxyRH22l8310WHUvy3HXD/1oL8gG3N/HI7+Pd6a+2cV+Ggfmflw
LPg5Cz82gq+v8GV78I8W/nwH+ZyUfLgG+cVJftyMfNMkX76A/OEfd8APo/jB
i/Dns/jD6kTx64n4xY0Bo9quUE03/OMiWSf4x4qJ//zlavi9iP1T4P8NnF+D
+chAfQ2Yn1jUX475CkF/mzB/Ceh/FvOZCj7gR17gB77UAr6RmH8L8O/D/TCO
fOAfleRKfs64X5KQbwXuH7tgyR/+0SGV+BGP+2sr/KnE/XY0Svxav//EP033
H340svk=
       "]]}}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlGlIlFEUhgfNHyahlmWJYmYEBSlSULh0jFySUsfGcIEwtTCyHEmQIHGh
ECXTJNREyyU1TUvDUizhoIONpdFCQhq5gMs4OuO4UGgL1ZzXH30wfAOX795z
nvc51y1Bfeq8hUKhiPj7+/eWR0fr/yoSRr9v3qsjr1hjVMlEOcdl6AdranVU
1z/ZdDP9IfuGXZuySZol69N1lbrIx3x/KtWgTNZTYeBHK5faFt4R+NN98t4c
aS+tWnV+fcDezU4NV6fnqbDgeJmlUc29ThX9hj1GatiobXyX3UQRDV1HXP0W
aG3QIiYgjEn5ozC22sJE7s1vNmg8ByimqifP28NEB3LiMtXRn8jkbeA2exMd
DOgb7B37Qo5DLon5/gukDK7fP7IyQbcdPIdCag2kNAWlqLZMU9nLDo3Kf46S
sorPvHfVU6f9h+wCZx1d3D359LrBQInxreeCjk1S7lzpieRGEw3ucsiqKBkj
g1G59M1uiX6NZ9bX1g3RsFO3W47rMs0ktN8aV7yiNuuIVC/tMlmnDXOrbamv
0Fuh37LOrVifkO95BN8PyP48j/3j5XzOw/nPpD5Wo74iqZ+voH70xyr0t136
53D0vyB8OBR8wI/3gR/48k7wBX+eAn/kwy+Qj4/kx8X5kh/y5efIF/nzXeTv
J37wWqT4cVb8YcvX4g/8YocY8Qv+cd5M+qp+pN23HOue0eZ1gn9cJP6RD/bP
kv2pCueb5HxyRH22l8310WHUvy3HXD/1oL8gG3N/HI7+Pd6a+2cV+Ggfmflw
LPg5Cz82gq+v8GV78I8W/nwH+ZyUfLgG+cVJftyMfNMkX76A/OEfd8APo/jB
i/Dns/jD6kTx64n4xY0Bo9quUE03/OMiWSf4x4qJ//zlavi9iP1T4P8NnF+D
+chAfQ2Yn1jUX475CkF/mzB/Ceh/FvOZCj7gR17gB77UAr6RmH8L8O/D/TCO
fOAfleRKfs64X5KQbwXuH7tgyR/+0SGV+BGP+2sr/KnE/XY0Svxav//EP033
H340svk=
      "]]}, {{}, {}}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0112862913174099`, 1.0112862913174099`}, {-1.25, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.812013464784708*^9, 3.812013506784391*^9}},
 CellLabel->"Out[9]=",ExpressionUUID->"4cb22cc2-b9ea-451f-86b4-01d7bc3148c3"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{915, 509},
WindowMargins->{{26, Automatic}, {Automatic, 130}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"582acb91-5e6b-48a8-930b-2b848d81f671"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 113, 0, 67, "Section",ExpressionUUID->"7e06fb0b-b50b-4986-8198-f2824b77e2f7"],
Cell[674, 22, 373, 9, 95, "Text",ExpressionUUID->"5f0e487f-5a05-4501-a484-5513630a1177"],
Cell[1050, 33, 156, 2, 30, "Input",ExpressionUUID->"f1ac7d12-1b5d-456a-b022-d764ffe5f377"],
Cell[1209, 37, 319, 8, 76, "Text",ExpressionUUID->"bbf09ff6-0254-43f2-80f3-ed48a7ada745"],
Cell[1531, 47, 177, 2, 30, "Input",ExpressionUUID->"24b49598-4151-4592-b0ba-fe777d476055"],
Cell[1711, 51, 369, 13, 53, "Text",ExpressionUUID->"9d33ae34-2de9-425a-b329-7615d03f9e1e"],
Cell[2083, 66, 265, 9, 120, "Input",ExpressionUUID->"118ce487-2ef8-4f01-9da6-c911a1ca4645"],
Cell[2351, 77, 218, 7, 53, "Text",ExpressionUUID->"87ea0d06-ccf5-4b06-a499-85401135ab16"],
Cell[2572, 86, 131, 2, 30, "Input",ExpressionUUID->"1d00279c-a5d8-4a27-915b-ba1d9b2c21e0"],
Cell[2706, 90, 220, 6, 53, "Text",ExpressionUUID->"3a43e4c7-9d7f-40b8-bf46-38a18da1bae8"],
Cell[2929, 98, 141, 2, 30, "Input",ExpressionUUID->"143af27d-00c6-4b33-b490-233e12389166"],
Cell[3073, 102, 175, 3, 53, "Text",ExpressionUUID->"751d6f93-221d-43c4-8623-0e47a4af5520"],
Cell[3251, 107, 335, 12, 174, "Input",ExpressionUUID->"89700eed-edde-4918-8ba9-616e5e7e2067"],
Cell[3589, 121, 176, 3, 53, "Text",ExpressionUUID->"eb88294c-0d5f-4888-a506-0a70ccd89c06"],
Cell[CellGroupData[{
Cell[3790, 128, 213, 5, 48, "Input",ExpressionUUID->"f79e2b70-ee90-4de0-9967-f354664946c3"],
Cell[4006, 135, 2312, 53, 449, "Output",ExpressionUUID->"0e6c2367-ad9f-4e02-9798-a6d9e76378d1"]
}, Open  ]],
Cell[6333, 191, 209, 5, 53, "Text",ExpressionUUID->"fd595950-2dfb-43a8-879a-5330b58cefd6"],
Cell[CellGroupData[{
Cell[6567, 200, 250, 6, 48, "Input",ExpressionUUID->"f40fdf31-0228-48c1-addf-a12bbbbed4fb"],
Cell[6820, 208, 2351, 54, 449, "Output",ExpressionUUID->"62081d7a-69fe-49a9-bdfd-21e6014bb7fa"]
}, Open  ]],
Cell[9186, 265, 166, 3, 53, "Text",ExpressionUUID->"7e42d331-662d-4ea0-adf9-045ef078dbae"],
Cell[CellGroupData[{
Cell[9377, 272, 196, 3, 30, "Input",ExpressionUUID->"60d050f5-80a7-4562-a1ae-59a8c770cc66"],
Cell[9576, 277, 3532, 75, 472, "Output",ExpressionUUID->"4cb22cc2-b9ea-451f-86b4-01d7bc3148c3"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

